==> aliyun-python-sdk-cas-1.0.12.tar.gz: aliyun-python-sdk-cas-1.0.12/aliyunsdkcas/request/v20200407/UploadUserCertificateRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcas.endpoint import endpoint_data

class UploadUserCertificateRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cas', '2020-04-07', 'UploadUserCertificate')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_EncryptCert(self): # String
		return self.get_query_params().get('EncryptCert')

	def set_EncryptCert(self, EncryptCert):  # String
		self.add_query_param('EncryptCert', EncryptCert)
	def get_Cert(self): # String
		return self.get_query_params().get('Cert')

	def set_Cert(self, Cert):  # String
		self.add_query_param('Cert', Cert)
	def get_Key(self): # String
		return self.get_query_params().get('Key')

	def set_Key(self, Key):  # String
		self.add_query_param('Key', Key)
	def get_EncryptPrivateKey(self): # String
		return self.get_query_params().get('EncryptPrivateKey')

	def set_EncryptPrivateKey(self, EncryptPrivateKey):  # String
		self.add_query_param('EncryptPrivateKey', EncryptPrivateKey)
	def get_SignPrivateKey(self): # String
		return self.get_query_params().get('SignPrivateKey')

	def set_SignPrivateKey(self, SignPrivateKey):  # String
		self.add_query_param('SignPrivateKey', SignPrivateKey)
	def get_SignCert(self): # String
		return self.get_query_params().get('SignCert')

	def set_SignCert(self, SignCert):  # String
		self.add_query_param('SignCert', SignCert)
	def get_Name(self): # String
		return self.get_query_params().get('Name')

	def set_Name(self, Name):  # String
		self.add_query_param('Name', Name)

==> aliyun-python-sdk-cas-1.0.13.tar.gz: aliyun-python-sdk-cas-1.0.13/aliyunsdkcas/request/v20200407/UploadUserCertificateRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcas.endpoint import endpoint_data

class UploadUserCertificateRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cas', '2020-04-07', 'UploadUserCertificate')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_EncryptCert(self): # String
		return self.get_query_params().get('EncryptCert')

	def set_EncryptCert(self, EncryptCert):  # String
		self.add_query_param('EncryptCert', EncryptCert)
	def get_Cert(self): # String
		return self.get_query_params().get('Cert')

	def set_Cert(self, Cert):  # String
		self.add_query_param('Cert', Cert)
	def get_ResourceGroupId(self): # String
		return self.get_query_params().get('ResourceGroupId')

	def set_ResourceGroupId(self, ResourceGroupId):  # String
		self.add_query_param('ResourceGroupId', ResourceGroupId)
	def get_Key(self): # String
		return self.get_query_params().get('Key')

	def set_Key(self, Key):  # String
		self.add_query_param('Key', Key)
	def get_EncryptPrivateKey(self): # String
		return self.get_query_params().get('EncryptPrivateKey')

	def set_EncryptPrivateKey(self, EncryptPrivateKey):  # String
		self.add_query_param('EncryptPrivateKey', EncryptPrivateKey)
	def get_SignPrivateKey(self): # String
		return self.get_query_params().get('SignPrivateKey')

	def set_SignPrivateKey(self, SignPrivateKey):  # String
		self.add_query_param('SignPrivateKey', SignPrivateKey)
	def get_SignCert(self): # String
		return self.get_query_params().get('SignCert')

	def set_SignCert(self, SignCert):  # String
		self.add_query_param('SignCert', SignCert)
	def get_Name(self): # String
		return self.get_query_params().get('Name')

	def set_Name(self, Name):  # String
		self.add_query_param('Name', Name)
